@@ -9,7 +9,7 @@ try {
 $dbh = new PDO(PDO_DNS,PDO_USER,PDO_PASS);
 $sth = $dbh ->prepare("INSERT INTO rental (user_name , book_name , date) VALUES (:NAME , :TITLE , :DAY)");
 
-$sth->bindValue(':NAME',$_SESSION['username']);
+$sth->bindValue(':NAME',$_SESSION['userid']);
 $sth->bindValue(':TITLE',$_SESSION['book_name']);
 $sth->bindValue(':DAY',$_SESSION['rental_day_db']);
 $result = $sth -> execute();
@@ -19,7 +19,6 @@ catch (PDOexception $e) {
 dump($e);
 exit;
 }
-// ---- view ---
 
 
 
