@@ -9,11 +9,15 @@ class Mysession_db extends Mysession {
 		try {
 			$dbh = new PDO($parms['DNS'], $parms['user'],$parms['password']);
 
+			$sql = 'SELECT * FROM '.$parms['table'].' WHERE userid LIKE :USERNAME AND userpass LIKE :PASS';
 			
-			$sth = $dbh->prepare( 'SELECT * FROM person WHERE username LIKE :USERNAME AND userpass LIKE :PASS');
+
+			$sth = $dbh->prepare( $sql);
+
 			
-			$sth ->bindValue(':USERNAME',$parms['username']);
+			$sth ->bindValue(':USERNAME',$parms['userid']);
 			$sth ->bindValue(':PASS',$parms['userpass']);
+
 			
 			$sth->execute();
 			$result = $sth->fetchAll();
@@ -31,8 +35,8 @@ class Mysession_db extends Mysession {
 
 		if($colcount === 1) {
 			$this->errmsg = (boolean)true;	
-			$this->setsession($parms['username']);
-
+			
+			$this->setsession($result[0]['userid'],$result[0]['username']);
 		}
 		
 		elseif($result != true ) {
