@@ -12,8 +12,8 @@ $parms = array (
 		"DNS"           =>PDO_DNS ,
 		"user"          =>PDO_USER ,
 		"password"      =>PDO_PASS,
-		"table"         =>'userinfo',
-		"username"      =>$_POST['id'],
+		"table"         =>'person',
+		"userid"        =>$_POST['id'],
 		"userpass"      =>$_POST['pass'],
 
 	       );
@@ -34,7 +34,7 @@ $session->start();
 
 
 if($_SESSION['tiket']==SESSIONPASS){
-	header("Location:". $_POST['continue']);
+	header("Location:http://localhost". $_GET['continue']);
 	exit;
 }       else {
 
