@@ -1,4 +1,4 @@
-<?php /* Smarty version 2.6.20, created on 2008-12-29 14:12:35
+<?php /* Smarty version 2.6.20, created on 2009-01-25 20:24:16
          compiled from entryed.tpl */ ?>
 <?php $_smarty_tpl_vars = $this->_tpl_vars;
 $this->_smarty_include(array('smarty_include_tpl_file' => "DTD.tpl", 'smarty_include_vars' => array()));
@@ -22,26 +22,26 @@ unset($_smarty_tpl_vars);
 	
 	<h2> ユーザ登録の完了 </h2>
 
-	<p>　鈴木将之さん 会員登録が完了しました </p> 
+	<p>　<?php echo $this->_tpl_vars['userinfo']['username']; ?>
+さん 会員登録が完了しました </p> 
 	
 	<div id="info">
 	<h3> 登録内容 </h3>
 	<ul>
 	<li> <span>学籍番号</span>:</li>
-	<li> 08JO0111 </li>
+	<li> <?php echo $this->_tpl_vars['userinfo']['userid']; ?>
+ </li>
 	</ul>
 	<br />
 	
 	<ul>
 	<li> <span>お名前</span>:</li>
-	<li>鈴木　将之 </li>
+	<li><?php echo $this->_tpl_vars['userinfo']['username']; ?>
+ </li>
 	</ul>
 	<br />
 	
-	<ul>
-	<li> <span>パスワード</span>:</li>
-	<li> pass </li>
-	</ul>
+		
 	</div>	
 	<div id="navi">
 	
